@@ -1,8 +1,8 @@
 import tensorflow as tf
 import numpy as np
-from .textPreprocessing import preprocess_text
+from .textPreprocessing.preprocess_text import preprocess_text
 from .navec_vectorizer_layer import get_navec_word_vectorizer
-from dev import make_sentence_vectorizer
+from .dev.utils.vectorize_sentence import make_sentence_vectorizer
 
 
 class ToxicCommentsDetector:
